pub fn parse_json_path<'a>(path: &'a str) -> Result<Vec<PathSegment<'a>>>Expand description
Parses JSONPath query string into a list of borrowed path segments. 解析 JSONPath 表达式为片段列表(零堆分配借用切片)
pub fn parse_json_path<'a>(path: &'a str) -> Result<Vec<PathSegment<'a>>>Parses JSONPath query string into a list of borrowed path segments. 解析 JSONPath 表达式为片段列表(零堆分配借用切片)